@@ -11,7 +11,7 @@ use URI;
 use URI::QueryParam;
 use URI::file;
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 has dsn => sub { _dsn_from_path(shift->_tempfile_path) };
 has max_connections => 5;
@@ -374,4 +374,4 @@ the terms of the Artistic License version 2.0.
 
 =head1 SEE ALSO
 
-L<Mojolicious>, L<DBD::SQLite>
+L<Mojolicious>, L<Mojo::Pg>, L<DBD::SQLite>
